@@ -25,7 +25,7 @@ def is_1d(x):
 def is_complex(x):
     return isinstance(x,(complex,np.complex64,np.complex128) )
 #-------------------------------------------------------------------
-def to_1d(x):
+def to_1d(data):
     '''
     Transform any data to 1d ndarray.
 
